@@ -45,7 +45,8 @@ def get_per_ome_feat_select_labels(subjects, meta_ome, ome_name = ''):
         if subj in meta_ome.label_dict:
             feat_labels.append(meta_ome.label_dict[subj])
         else:
-            sys.exit("there is a subject in ome:\n\t"+ome_name+"\nthat we couldn't find in the meta_ome")
+            feat_labels.append("NA")
+            print("WARNING: there is a subject in ome:\n\t"+ome_name+"\nthat we couldn't find in the meta_ome")
     return(feat_labels)
 
 
@@ -580,7 +581,7 @@ def analyze_group_differences(meta_ome,
         temp_out_dir = process_dir(out_dir + ome.name)
         per_ome_directories = []
         print("working on ome:", ome.name)
-        feat_select_labels = get_per_ome_feat_select_labels(ome.subjects, meta_ome)
+        feat_select_labels = get_per_ome_feat_select_labels(ome.subjects, meta_ome, ome_name = ome.name)
         ## list of lists index in first list is sample group number, entry within these are indices 
         ## of the samples within this particular ome
         temp_sample_k_lists = get_sample_k_lists(feat_select_labels)
@@ -730,7 +731,8 @@ def main(args):
                                                      processes = args.processes, 
                                                      bin_size = args.bin_size, 
                                                      process_mem = args.mem_per_node,
-                                                     out_dir = args.out_dir)
+                                                     out_dir = args.out_dir,
+                                                     include_subjects = meta_ome.all_subjects)
     analyze_group_differences(meta_ome, 
                               args.out_dir, 
                               args.alpha, 
