@@ -129,9 +129,23 @@ def remove_invarainat_features(in_mat):
     return(in_mat[:,keep_col_vect])
 
 
-def filter_none_subjects(in_mat):
+def filter_cat_for_keep_subjects(in_mat, include_subjects):
+    print("Filtering for appropriate subjects:", in_mat.shape)
+    rm_rows = []
+    for i in range(1,in_mat.shape[0]):
+        if in_mat[i,0] not in include_subjects:
+            rm_rows.append(i)
+    out_mat = np.delete(in_mat,rm_rows, axis = 0)
+    print(out_mat.shape)
+    return(out_mat)
+
+
+def filter_none_subjects(in_mat, include_subjects = None):
     if isinstance(in_mat,list):
         in_mat = np.array(in_mat)
+    if include_subjects is not None:
+        ## keep only the subjects that are in the list
+        in_mat = filter_cat_for_keep_subjects(in_mat, include_subjects)
     ## get rid of invariant features
     in_mat = remove_invarainat_features(in_mat)
 
@@ -210,7 +224,7 @@ def log_loss(y_true, y_pred, eps = 1e-15):
 
 class categorical_ome():
     """ this class is for any categorical ome """
-    def __init__(self, in_mat, path = None, name = None, plot = False):
+    def __init__(self, in_mat, path = None, name = None, plot = False, include_subjects = None):
         ## rows are subjects, columns are features
         if name != None:
             self.name = name
@@ -219,7 +233,7 @@ class categorical_ome():
             print('\t',self.name)
         else:
             self.name = None
-        self.original_mat = filter_none_subjects(in_mat)
+        self.original_mat = filter_none_subjects(in_mat, include_subjects = include_subjects)
         self.randomized_original_mat = deepcopy(self.original_mat)
         self.feature_names = self.original_mat[0,1:]
         self.all_feature_names = deepcopy(self.feature_names)
@@ -463,6 +477,8 @@ class categorical_ome():
             
         self.good_feature_indices = np.where(self.max_of_min_diff>0.15)[0]#get_sd_from_beta(self.max_of_min_diff))[0]
         print('\n\nfound',self.good_feature_indices.shape[0],'good features out of',self.max_of_min_diff.shape[0])
+        print("\n\nBECAUSE WE FOUND NO HIGH INFORMATION FEATURES, WE'LL JUST DO IT ON EVERYTHING")
+        self.good_feature_indices = np.array(list(range(self.max_of_min_diff.shape[0])),dtype=int)
         return(categorical_ome(self.original_mat[:,np.array([0]+list(self.good_feature_indices+1),dtype=int)], name = self.name+"_high_info"))
         # sns.clustermap(self.num_times_pair_better_than_random)
         # plt.show()
@@ -681,6 +697,8 @@ class categorical_ome():
             del pairwise_results[1]
         if len(pairwise_results) > 0:
             pairwise_results = np.array(pairwise_results[0])
+        else:
+            pairwise_results = np.array(pairwise_results)
         if pairwise_results.shape[0] > 0:
             temp_uncorrected_p = np.array(pairwise_results[:,-1], dtype = float).tolist()
             temp_corrected_p = correct_pvalues_for_multiple_testing(temp_uncorrected_p)
@@ -696,6 +714,8 @@ class categorical_ome():
             self.summarize_pairwise_group_differences(final_output, out_dir)
 
             ## write the summary table
+            if len(final_output)==0:
+                final_output = np.array(([['None','None','None','None','None','None','None','None']]))
             header = np.array(([['feature_name','group_1','group_2','mode_1','mode_2','chi_statistic','uncorrected_p','BH_corrected_p']]))
             final_output = np.concatenate((header, final_output))
         else:
