@@ -607,17 +607,18 @@ def process_test_omes(test_cat = [],
                       processes = 1, 
                       bin_size = 5000, 
                       process_mem = 20,
-                      out_dir = None):
+                      out_dir = None,
+                      include_subjects = None):
     ## process the test omes if present
     test_cat_omes = []
     for cat in test_cat:
         print('\n\nprocessing test cat ome:\n',cat)
-        test_cat_omes.append(categorical_ome(get_in_mat(cat, missing_str), path=cat))
+        test_cat_omes.append(categorical_ome(get_in_mat(cat, missing_str), path=cat, include_subjects = include_subjects))
         test_cat_omes[-1].process_cat_ome()
     test_num_omes = []
     for infile in test_num:
         print('processing test num ome:\n',infile)
-        in_mat, feature_names, subjects = process_data_file(infile)
+        in_mat, feature_names, subjects = process_data_file(infile, include_subjects = include_subjects)
         test_num_omes.append(num_ome(in_mat, feature_names, subjects, all_features=True, infile = infile, processes = processes, bin_size = bin_size, process_mem = process_mem, out_dir = out_dir))
     return(test_cat_omes, test_num_omes)
 
@@ -671,7 +672,8 @@ def mana_clust(out_dir,
                                                          processes = args.processes, 
                                                          bin_size = args.bin_size, 
                                                          process_mem = args.mem_per_node,
-                                                         out_dir = args.out_dir)
+                                                         out_dir = args.out_dir,
+                                                         include_subjects = meta_ome.all_subjects)
         ## now do all of the analyses
         analyze_group_differences(meta_ome, 
                                   args.out_dir, 
