@@ -271,6 +271,8 @@ class num_ome():
         self.all_features = all_features
         self.all_feature_names = deepcopy(self.all_features)
         ## get the bins
+        print(self.in_mat)
+        print(in_mat)
         self.get_good_features_and_norm(all_features = self.all_features)
         self.get_affinity_matrix()
 
@@ -344,11 +346,16 @@ class num_ome():
         """ takes the input matrix (features in rows, samples in columns) """
         if not all_features:
             variable_indices = self.get_variant_indices()
+            print(self.in_mat)
             self.in_mat = self.in_mat[variable_indices,:]
+            print(self.in_mat)
             self.feature_names = self.feature_names[variable_indices]
+            if len(variable_indices)<2:
+                print("\n\nWE ONLY FOUND",len(variable_indices),"VARIABLE(S) WITH VARIANCE, so we'll just use them all")
         self.bins = self.get_bins(bin_size = self.bin_size)
         
         ## min-max normalize the rows
+        print(self.in_mat.shape)
         self.in_mat -= np.transpose(np.array([np.min(self.in_mat, axis=1)]))
         self.in_mat /= np.transpose(np.array([np.max(self.in_mat, axis=1)]))
 
@@ -492,7 +499,7 @@ class num_ome():
             if index_passes:
                 self.anti_cor_indices.append(i)
         self.anti_cor_indices = np.array(self.anti_cor_indices)
-        for i in range(0,100):
+        for i in range(0,min([100,len(self.total_neg_cor)])):
             print(self.total_neg_cor[i],
                   self.expected_neg_cor[i],
                   self.sig_neg_cor[i])
@@ -922,8 +929,21 @@ class num_ome():
 
 
 ########################################################################
-def process_data_file(in_path, dtype = np.float32):
+def filter_num_subjects(in_mat_full, include_subjects):
+    print("Filtering numeric dataset for appropriate subjects:",in_mat_full.shape)
+    rm_col = []
+    for i in range(1,in_mat_full.shape[1]):
+        if in_mat_full[0,i] not in include_subjects:
+            rm_col.append(i)
+    out_mat = np.delete(in_mat_full, rm_col, axis = 1)
+    print(out_mat.shape)
+    return(out_mat)
+
+
+def process_data_file(in_path, dtype = np.float32, include_subjects = None):
     in_mat_full = np.array(read_table(in_path))
+    if include_subjects is not None:
+        in_mat_full = filter_num_subjects(in_mat_full, include_subjects)
     in_mat = np.array(in_mat_full[1:,1:],dtype=dtype)
     subjects = in_mat_full[0,1:]
     feature_names = in_mat_full[1:,0]
@@ -935,6 +955,9 @@ def do_all_numeric_omes(infile_list, processes = 1, bin_size = 5000, force = Tru
     all_num_omes = []
     for infile in infile_list:
         in_mat, feature_names, subjects = process_data_file(infile)
+        if subjects.shape[0]==0:
+            print("\n\n\n","WARNING: WE DIDN'T FIND ANY MATCHING SUBJECT IDS IN:",infile,"\n")
+            print("try checking the subject IDs or whether the input file needs to be transposed")
         all_num_omes.append(num_ome(in_mat, feature_names, subjects, infile = infile, processes = processes, bin_size = bin_size, force = force, no_h5 = no_h5, process_mem = process_mem, out_dir = out_dir))
         all_num_omes_full.append(num_ome(in_mat, feature_names, subjects, all_features=True, infile = infile, processes = processes, bin_size = bin_size, process_mem = process_mem, out_dir = out_dir))
     return(all_num_omes_full, all_num_omes)
